@@ -29,6 +29,7 @@ def dag_factory_atomic(
     additional_dag_args: Optional[dict] = None,
     additional_task_args: Optional[dict] = None,
     logging_func: Optional[Callable] = None,
+    dagrun_timeout_factor: Optional[float] = 0.8,
     **kwargs
 ) -> Tuple[DAG]:
     def raise_exception(msg: str) -> None:
@@ -70,6 +71,18 @@ def dag_factory_atomic(
         # Make sure only one execution every runs scheduled but manual triggers work!
         end_date = start_date + 2 * schedule_interval - timedelta(seconds=1)
 
+    if dagrun_timeout_factor:
+        _msg = "dagrun_timeout_factor must be a number between 0 and 1!"
+        assert isinstance(dagrun_timeout_factor, (int, float)) and (
+            0 < dagrun_timeout_factor <= 1
+        ), _msg
+        dagrun_timeout = dagrun_timeout_factor * schedule_interval
+        additional_task_args["execution_timeout"] = additional_task_args.get(
+            "execution_timeout", dagrun_timeout
+        )
+    else:  # In case of 0 set to None
+        dagrun_timeout = None
+
     dag = DAG(
         dag_name,
         catchup=True,  # See above
@@ -78,6 +91,7 @@ def dag_factory_atomic(
         schedule_interval=schedule_interval,
         start_date=start_date,
         end_date=end_date,
+        dagrun_timeout=dagrun_timeout,
         **additional_dag_args,
     )
 
